pub struct Annotation {Show 16 fields
pub id: String,
pub created: OffsetDateTime,
pub updated: OffsetDateTime,
pub user: UserAccountID,
pub uri: String,
pub text: String,
pub tags: Vec<String>,
pub group: String,
pub permissions: Permissions,
pub target: Vec<Target>,
pub links: HashMap<String, String>,
pub hidden: bool,
pub flagged: bool,
pub document: Option<Document>,
pub references: Vec<String>,
pub user_info: Option<UserInfo>,
}Expand description
Full representation of an Annotation resource and applicable relationships.
Fields
id: StringAnnotation ID
created: OffsetDateTimeDate of creation
updated: OffsetDateTimeDate of last update
user: UserAccountIDUser account ID in the format “acct:
uri: StringURL of document this annotation is attached to
text: StringThe text content of the annotation body (NOT the selected text in the document)
Tags attached to annotation
group: StringThe unique identifier for the annotation’s group
permissions: Permissionstarget: Vec<Target>Which part of the document does the annotation target.
links: HashMap<String, String>An object containing hypermedia links for this annotation
Whether this annotation is hidden from public view
flagged: boolWhether this annotation has one or more flags for moderation
document: Option<Document>Document information
references: Vec<String>Annotation IDs for any annotations this annotation references (e.g. is a reply to)
user_info: Option<UserInfo>Implementations
Sourceimpl Annotation
impl Annotation
pub fn update(&mut self, annotation: InputAnnotation)