TextPositionSelector

Struct TextPositionSelector 

pub struct TextPositionSelector {
    pub start: u64,
    pub end: u64,
}
This Selector describes a range of text by recording the start and end positions of the selection in the stream. Position 0 would be immediately before the first character, position 1 would be immediately before the second character, and so on. The start character is thus included in the list, but the end character is not.

For example, if the document was “abcdefghijklmnopqrstuvwxyz”, the start was 4, and the end was 7, then the selection would be “efg”. Web Annotation Data Model - Text Position Selector

Fields

start: u64

The starting position of the segment of text. The first character in the full text is character position 0, and the character is included within the segment.

end: u64

The end position of the segment of text. The character is not included within the segment.