pub struct Group {
pub id: String,
pub groupid: Option<String>,
pub name: String,
pub links: Links,
pub organization: Organization,
pub scopes: Option<Scope>,
pub scoped: bool,
pub group_type: Type,
}Expand description
Information returned about a Group resource
Fields
id: StringGroup ID
groupid: Option<String>Authority-unique identifier that may be set for groups that are owned by a third-party authority. This field is currently present but unused for first-party-authority groups.
name: StringGroup name
links: LinksURL to the group’s main (activity) page
organization: OrganizationThe organization to which this group belongs.
scopes: Option<Scope>Information about the URL restrictions for annotations within this group.
scoped: boolWhether or not this group has URL restrictions for documents that may be annotated within it. Non-scoped groups allow annotation to documents at any URL
group_type: TypeIs the groyp private, open, or restricted