pub struct TextQuoteSelector {
pub exact: String,
pub prefix: String,
pub suffix: String,
}Expand description
This Selector describes a range of text by copying it, and including some of the text immediately before (a prefix) and after (a suffix) it to distinguish between multiple copies of the same sequence of characters.
For example, if the document were again “abcdefghijklmnopqrstuvwxyz”, one could select “efg” by a prefix of “abcd”, the match of “efg” and a suffix of “hijk”. Web Annotation Data Model - Text Quote Selector
Fields
exact: StringA copy of the text which is being selected, after normalization.
prefix: StringA snippet of text that occurs immediately before the text which is being selected.
suffix: StringThe snippet of text that occurs immediately after the text which is being selected.